PocketProtector's CHANGELOG
============================

PocketProtector is a growing utility! This document records its growth.

PocketProtector uses the [CalVer](https://calver.org) versioning
scheme (`YY.MINOR.MICRO`).

Check this page when upgrading, we strive to keep the updates
summarized and readable.

18.0.1
------
*(August 22, 2018)*

Fix a schema validation error that occurred when loading a protected
file, due to a breaking change in `ruamel.yaml` version
0.15.55. That's [0ver](https://0ver.org/), folks.

18.0.0
------
*(February 5, 2018)*

Initial release with complete featureset.
